==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/it.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Non puoi rimuovere il tuo permesso di lettura.",
    "Team folders" : "Cartelle del team",
    "Admin configured folders shared with everyone in a team" : "Cartelle configurate dall'amministratore condivise con tutti i membri di un team",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Cartelle configurate dall'amministratore condivise con tutti in un team.\n\nLe cartelle possono essere configurate da *Cartelle team* nelle impostazioni dell'amministratore.\n\nDopo aver creato una cartella, l'amministratore può concedere l'accesso alla cartella a uno o più team, controllare i loro permessi di scrittura/condivisione e assegnare una quota per la cartella.\nA partire da Hub 10/Nextcloud 31, l'amministratore deve far parte del team per potergli assegnare una cartella Team.",
    "Unset" : "Rimuovi",
    "Denied (Inherited permission)" : "Negato (autorizzazione ereditata)",
    "Allowed (Inherited permission)" : "Consentito (autorizzazione ereditata)",
    "Denied" : "Negato",
    "Allowed" : "Consentito",
    "Access denied" : "Accesso negato",
    "Access allowed" : "Accesso consentito",
    "Inherit permission" : "Eredita permesso",
    "Deny" : "Nega",
    "Allow" : "Consenti",
    "Group" : "Gruppo",
    "Team" : "Team",
    "Team folder" : "Cartella del team",
    "Read" : "Lettura",
    "Write" : "Scrittura",
    "Create" : "Crea",
    "Delete" : "Elimina",
    "Share" : "Condivisione",
    "You" : "Tu",
    "Remove access rule" : "Rimuovi regola di accesso",
    "Add advanced permission rule" : "Aggiungi regola di autorizzazione avanzata",
    "Select a user or group" : "Seleziona un utente o gruppo",
    "Open Team folder" : "Apri cartella del team",
    "Permission denied. User does not have sufficient permissions." : "Permesso negato. L'utente non ha permessi sufficienti.",
    "Unexpected status from server" : "Stato non previsto dal server",
    "List of Team folders." : "Elenco delle cartelle del team.",
    "No Team folders yet" : "Nessuna cartella ancora per il team",
    "Team folders will show up here" : "Le cartelle del team verranno visualizzate qui",
    "Add group" : "Aggiungi gruppo",
    "Default" : "Predefinito",
    "Unlimited" : "Illimitata",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Vuoi veramente eliminare \"{folderName}\" e i file in essa contenuti? Questa operazione non può essere annullata",
    "Delete \"{folderName}\"?" : "Vuoi eliminare \"{folderName}\"?",
    "Team folder admin delegation" : "Delega amministratore cartella team",
    "They will have access to all Team folders." : "Avranno accesso a tutte le cartelle del team.",
    "They will only have access to Team folders for which they have advanced permissions." : "Avranno accesso solo alle cartelle del team per le quali dispongono di autorizzazioni avanzate.",
    "Group or team" : "Gruppo o team",
    "Sort by number of groups or teams that have access to this folder" : "Ordina per numero di gruppi o team che hanno accesso a questa cartella",
    "Sort by number of groups that have access to this folder" : "Ordina per numero di gruppi che hanno accesso a questa cartella",
    "Folder name" : "Nome della cartella",
    "Quota" : "Quota",
    "Advanced Permissions" : "Autorizzazioni avanzate",
    "Pagination of team folders" : "Impaginazione delle cartelle del team",
    "Previous" : "Precedente",
    "Next" : "Successivo",
    "User" : "Utente",
    "Unknown" : "Sconosciuto",
    "Users/groups that can manage" : "Utenti/gruppi che possono gestire",
    "None" : "Nessuno",
    "No other groups or teams available" : "Nessun altro gruppo o team disponibile",
    "No other groups available" : "Nessun altro gruppo disponibile",
    "{displayName} (team)" : "{displayName} (team)",
    "Add group or team" : "Aggiungi gruppo o team",
    "{size} used" : "{size} utilizzati",
    "Other …" : "Altro...",
    "You can not remove your own read permission." : "Non puoi rimuovere la tua autorizzazione di lettura.",
    "Group folders" : "Cartelle di gruppo",
    "Admin configured folders shared with everyone in a group" : "Cartelle configurate dagli amministratori condivise con chiunque in un gruppo",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Cartelle configurate dall'amministratore e condivise con tutti i membri di un gruppo. \n\nLe cartelle possono essere configurate da *Cartelle di gruppo* in impostazioni di amministratore. \n\nDopo aver creato una cartella, l'amministratore può concedere l'accesso alla cartella a uno o più gruppi, controllare i loro permessi di scrittura/condivisione e assegnare una quota per la cartella.",
    "Group folder" : "Cartella di gruppo",
    "Open group folder" : "Apri cartella di gruppo",
    "List of group folders." : "Elenco delle cartelle di gruppo.",
    "No group folders yet" : "Nessuna cartella di gruppo ",
    "Group folders will show up here" : "Le cartelle di gruppo verranno visualizzate qui",
    "Group folder admin delegation" : "Delega amministratore cartella di gruppo",
    "They will have access to all group folders." : "Avranno accesso a tutte le cartelle del gruppo.",
    "They will only have access to group folders for which they have advanced permissions." : "Avranno accesso solo alle cartelle di gruppo per le quali dispongono di autorizzazioni avanzate.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Cartelle configurate dall'amministratore condivise con tutti in un team.\n\nLe cartelle possono essere configurate da *Cartelle del team* nelle impostazioni dell'amministratore.\n\nDopo aver creato una cartella, l'amministratore può concedere l'accesso alla cartella a uno o più team, controllare i loro permessi di scrittura/condivisione e assegnare una quota per la cartella."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/it.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Non puoi rimuovere il tuo permesso di lettura.",
    "Team folders" : "Cartelle del team",
    "Unset" : "Rimuovi",
    "Denied (Inherited permission)" : "Negato (autorizzazione ereditata)",
    "Allowed (Inherited permission)" : "Consentito (autorizzazione ereditata)",
    "Denied" : "Negato",
    "Allowed" : "Consentito",
    "Access denied" : "Accesso negato",
    "Access allowed" : "Accesso consentito",
    "Inherit permission" : "Eredita permesso",
    "Deny" : "Nega",
    "Allow" : "Consenti",
    "Group" : "Gruppo",
    "Team" : "Team",
    "Team folder" : "Cartella del team",
    "Read" : "Lettura",
    "Write" : "Scrittura",
    "Create" : "Crea",
    "Delete" : "Elimina",
    "Share" : "Condivisione",
    "You" : "Tu",
    "Remove access rule" : "Rimuovi regola di accesso",
    "Add advanced permission rule" : "Aggiungi regola di autorizzazione avanzata",
    "Select a user or group" : "Seleziona un utente o gruppo",
    "Open Team folder" : "Apri cartella del team",
    "Permission denied. User does not have sufficient permissions." : "Permesso negato. L'utente non ha permessi sufficienti.",
    "Unexpected status from server" : "Stato non previsto dal server",
    "List of Team folders." : "Elenco delle cartelle del team.",
    "No Team folders yet" : "Nessuna cartella ancora per il team",
    "Team folders will show up here" : "Le cartelle del team verranno visualizzate qui",
    "Add group" : "Aggiungi gruppo",
    "Default" : "Predefinito",
    "Unlimited" : "Illimitata",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Vuoi veramente eliminare \"{folderName}\" e i file in essa contenuti? Questa operazione non può essere annullata",
    "Delete \"{folderName}\"?" : "Vuoi eliminare \"{folderName}\"?",
    "Team folder admin delegation" : "Delega amministratore cartella team",
    "They will have access to all Team folders." : "Avranno accesso a tutte le cartelle del team.",
    "They will only have access to Team folders for which they have advanced permissions." : "Avranno accesso solo alle cartelle del team per le quali dispongono di autorizzazioni avanzate.",
    "Group or team" : "Gruppo o team",
    "Sort by number of groups or teams that have access to this folder" : "Ordina per numero di gruppi o team che hanno accesso a questa cartella",
    "Sort by number of groups that have access to this folder" : "Ordina per numero di gruppi che hanno accesso a questa cartella",
    "Folder name" : "Nome della cartella",
    "Quota" : "Quota",
    "Advanced Permissions" : "Autorizzazioni avanzate",
    "Pagination of team folders" : "Impaginazione delle cartelle del team",
    "Previous" : "Precedente",
    "Next" : "Successivo",
    "User" : "Utente",
    "Unknown" : "Sconosciuto",
    "Users/groups that can manage" : "Utenti/gruppi che possono gestire",
    "None" : "Nessuno",
    "No other groups or teams available" : "Nessun altro gruppo o team disponibile",
    "No other groups available" : "Nessun altro gruppo disponibile",
    "{displayName} (team)" : "{displayName} (team)",
    "Add group or team" : "Aggiungi gruppo o team",
    "{size} used" : "{size} utilizzati",
    "Other …" : "Altro...",
    "You can not remove your own read permission." : "Non puoi rimuovere la tua autorizzazione di lettura.",
    "Group folders" : "Cartelle di gruppo",
    "Admin configured folders shared with everyone in a group" : "Cartelle configurate dagli amministratori condivise con chiunque in un gruppo",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Cartelle configurate dall'amministratore e condivise con tutti i membri di un gruppo. \n\nLe cartelle possono essere configurate da *Cartelle di gruppo* in impostazioni di amministratore. \n\nDopo aver creato una cartella, l'amministratore può concedere l'accesso alla cartella a uno o più gruppi, controllare i loro permessi di scrittura/condivisione e assegnare una quota per la cartella.",
    "Group folder" : "Cartella di gruppo",
    "Open group folder" : "Apri cartella di gruppo",
    "List of group folders." : "Elenco delle cartelle di gruppo.",
    "No group folders yet" : "Nessuna cartella di gruppo ",
    "Group folders will show up here" : "Le cartelle di gruppo verranno visualizzate qui",
    "Group folder admin delegation" : "Delega amministratore cartella di gruppo",
    "They will have access to all group folders." : "Avranno accesso a tutte le cartelle del gruppo.",
    "They will only have access to group folders for which they have advanced permissions." : "Avranno accesso solo alle cartelle di gruppo per le quali dispongono di autorizzazioni avanzate.",
    "Admin configured folders shared with everyone in a team" : "Cartelle configurate dall'amministratore condivise con tutti i membri di un team",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Cartelle configurate dall'amministratore condivise con tutti in un team.\n\nLe cartelle possono essere configurate da *Cartelle del team* nelle impostazioni dell'amministratore.\n\nDopo aver creato una cartella, l'amministratore può concedere l'accesso alla cartella a uno o più team, controllare i loro permessi di scrittura/condivisione e assegnare una quota per la cartella.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Cartelle configurate dall'amministratore condivise con tutti in un team.\n\nLe cartelle possono essere configurate da *Cartelle team* nelle impostazioni dell'amministratore.\n\nDopo aver creato una cartella, l'amministratore può concedere l'accesso alla cartella a uno o più team, controllare i loro permessi di scrittura/condivisione e assegnare una quota per la cartella.\nA partire da Hub 10/Nextcloud 31, l'amministratore deve far parte del team per potergli assegnare una cartella Team."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
